/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 * 
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */

package org.objectweb.medor.expression.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.medor.expression.api.BinaryLogicalOperator;
import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.MalformedExpressionException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.expression.api.ParameterOperand;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public abstract class BasicBinaryLogicalOperator
        extends BasicBinaryOperator
        implements BinaryLogicalOperator {

    public BasicBinaryLogicalOperator() {
        super(PTypeSpace.BOOLEAN);
    }

	public BasicBinaryLogicalOperator(Expression e0, Expression e1) {
		super(PTypeSpace.BOOLEAN, e0, e1);
	}
    // IMPLEMENTATION OF THE Expression INTERFACE //
    //--------------------------------------------//

    public org.objectweb.medor.expression.api.Operand evaluate(ParameterOperand[] pos, Object o)
            throws ExpressionException {
        if (result == null) {
            throw new IllegalStateException("Unevaluable Expression: Not compiled");
        }
        result.setValue(evaluate(
							expressions[0].evaluate(pos, o).getBoolean(),
                            expressions[1].evaluate(pos, o).getBoolean()));
		return result;
    }

    // IMPLEMENTATION OF THE BinaryLogicalOperator INTERFACE //
    //-------------------------------------------------------//

    public abstract boolean evaluate(boolean b1, boolean b2);

    public Operand compileExpression() throws ExpressionException, MalformedExpressionException {
        compileExpression();
        checkOperands(new PType[][]{
                {PTypeSpace.BOOLEAN, PTypeSpace.BOOLEAN},
        });
        verified = true;
        result = new BasicVariableOperand(type);
        return result;
    }
}
