/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 * 
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */

package org.objectweb.medor.expression.lib;

import org.objectweb.medor.expression.api.BinaryOperator;
import org.objectweb.medor.expression.api.Expression;
import org.objectweb.jorm.type.api.PType;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public abstract class BasicBinaryOperator extends BasicOperator
		implements BinaryOperator {

	public BasicBinaryOperator() {
		super(new Expression[2]);
	}

	public BasicBinaryOperator(Expression e0, Expression e1) {
		super(new Expression[]{e0, e1});
	}

	public BasicBinaryOperator(PType type) {
		super(type, new Expression[2]);
	}

	public BasicBinaryOperator(PType type, Expression e0, Expression e1) {
		super(type, new Expression[]{e0, e1});
	}

	// IMPLEMENTATION OF THE BinaryOperator INTERFACE //
	//------------------------------------------------//

	public void setLeftExpression(Expression leftChild)
		throws IllegalStateException {
		if (!verified) {
			expressions[0] = leftChild;
		}
		else
			throw new IllegalStateException("Compiled expression can't be modified");
	}

	public void setRightExpression(Expression rightChild)
		throws IllegalStateException {
		if (!verified) {
			expressions[1] = rightChild;
		}
		else
			throw new IllegalStateException("Compiled expression can't be modified");
	}

	public Expression getLeftExpression() {
		return expressions[0];
	}

	public Expression getRightExpression() {
		return expressions[1];
	}

}
