/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.MalformedExpressionException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.expression.api.ParameterOperand;

/**
 * Is an operator to upper string operand.
 *
 * @author S.Chassande-Barrioz
 */
public class StringUpper extends BasicUnaryOperator {

    private static final long serialVersionUID = -8971766058220002736L;

    public StringUpper() {
		super(PTypeSpace.STRING);
	}
	public StringUpper(Expression strOperand) {
		super(PTypeSpace.STRING, strOperand);
	}

	public String getOperatorString() {
		return STRING_UPPER;
	}

	public Operand evaluate(ParameterOperand[] pos, Object o)
		throws ExpressionException {
		if (expressions[0] == null) {
			throw new MalformedExpressionException("Null children value");
		}
		if (result == null) {
			throw new ExpressionException("Expression not compiled");
		}
		result.setValue(
				evaluate(getExpression(0).evaluate(pos, o).getString()));
		return result;
	}

	public Operand compileExpression()
		throws ExpressionException, MalformedExpressionException {
        compileOperands();
        compileOperands();
        checkOperands(new PType[][]{ {PTypeSpace.STRING} });
        result = new BasicVariableOperand(type);
        verified = true;
		return result;
	}

	public String evaluate(String str) {
		return (str == null ? null : str.toUpperCase());
	}
}
